// C Source File
// Created 1/1/2006; 10:03:08 AM
// Tron v1.00 - By Tyler Cassidy
// (C) Copyright 2006 Tyler Cassidy. All Rights Reserved.
// Email: altadogsledder89@yahoo.ca
//        tyler@tylerc.org
// Website: none yet
// ** Note: I will not be responsible for anything that this game game does to your calculator!

// Definitions
// #define MIN_AMS 200 // Only Enable this if you are not using TIGCC IDE

// Lets setup some Integers and so on
volatile long int timer; // Timer Integer
long int speed_timing; // For Speed timing
unsigned int game_score; // Game Score
short game_sequence, game_on, game_speed, game_over, game_paused; // General Shorts
short mm_selector, pt_selector; // Menu Shorts

void *kbq; // For Keyboard Queue
unsigned short key; // For Keyboard Queue

// Voids for Saving the Screen Data
void *DarkPlaneData;
void *LightPlaneData;

#include <tigcclib.h> // All TIGCC Header Files
#include "extgraph.h" // ExtGraph Library v2.00 B5
#include "tron.h" // Tron Header File
#include "ai.h" // Artificial Intellegence Header File
#include "engine.h" // Game Engine Header File

// Lets call the Structures Now
GAMEHIGHSCORES gamehighscores; // For Game Highscores
GAMEPLAY gameplay; // For In-Game Information

/// Lets Setup AI5 to add a timer to it.
INT_HANDLER oldai5 = NULL; // Need a place to put OLD AI5 Handler For Now

DEFINE_INT_HANDLER(ai5timer) {
	timer++; // Increment to Timer
	ExecuteHandler(oldai5); // Run old AI5 Timer
}

/// Main Function
void _main(void)
{
  /// Lets Initialize the Game
  if ((DarkPlaneData = malloc(LCD_SIZE)) == FALSE) return;
  if ((LightPlaneData = malloc(LCD_SIZE)) == FALSE) {
    free(DarkPlaneData);
    return;	
  }
  /// End of Game Initialization
  
	// Lets Turn on Grayscale
	if (!GrayOn()) return; // If cannot start Grayscale, turn off.
	
	// Lets setup the AI5 Timer
	oldai5 = GetIntVec(AUTO_INT_5); // Saved old AI5 Handler
	timer = 0; // Set Timer to 0
	SetIntVec(AUTO_INT_5, ai5timer); // Setup AI5 Timer Handler
	
	// Now Lets setup a Keyboard Queue
	kbq = kbd_queue();
	
	// Lets the intro screen
	game_sequence = INTRO_SCREEN; // Setup for Intro Screen on Launch
	
  // Lets Load Game Settings
  game_speed = 2; // Set to Normal; Now Lets setup the game setting
  ClearHighScores(); // Lets Clear the Highscores
  FE_LoadSettings(); // Game Settings Loaded
  game_on = 0; // Lets make sure game is off
	
	/// Main Core Loop
	while(1) {
		// Introduction Sequence
		if (game_sequence == INTRO_SCREEN) show_intro(); // Show Introduction Screen
		
		// Main Menu Sequence
		if (game_sequence == MAIN_MENU) show_mainmenu(); // Show Game Main Menu
		
		// Play Tron Game Sequence
		if (game_sequence == PLAY_GAME) TronEngine_PlayTron(); // Play Tron!

		// Game Setup Sequence
		if (game_sequence == GAME_SETUP) show_playtronmenu(); // Show Play Tron Menu
		
		// Highscores Sequence
		if (game_sequence == HIGHSCORES_MENU) show_gamescores(); // Show Game High Scores
		
		// Quit Game Sequence
		if (game_sequence == QUIT_GAME) {
			game_on = 0; // Make sure game is off
			break; // Break out of Main Core Loop and kill!
		}
	}
	/// End of Main Core Loop
	
	// Lets Free the Reserved Memory so the calculator does bloat!
  free(DarkPlaneData); // Clear Dark Plane Data
  free(LightPlaneData); // Clear LightPlaneData
	
	// Lets save the High Scores
	FE_SaveSettings();
	
	// Time to wrap up the running of the game ;)
	SetIntVec(AUTO_INT_5, oldai5); // Restore old AI5 Handler
	GrayClearScreen(); // Clear Screen
	GrayOff(); // Turn off Grayscale
	GKeyFlush(); // Flush the Keyboard Queue :)
}
